#!/bin/sh -e
##
## Repulling a suspended patch
##
## Copyright (C) 2012 Ganesh Sittampalam
##
## Permission is hereby granted, free of charge, to any person
## obtaining a copy of this software and associated documentation
## files (the "Software"), to deal in the Software without
## restriction, including without limitation the rights to use, copy,
## modify, merge, publish, distribute, sublicense, and/or sell copies
## of the Software, and to permit persons to whom the Software is
## furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be
## included in all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
## EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
## MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
## NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
## BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
## ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
## CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
## SOFTWARE.

. lib

rm -rf R
mkdir R
cd R
darcs init
echo 'wibble' > wibble
darcs rec -lam "add wibble"
darcs tag bla
cd ..

# suspend, repull, rebase obliterate

rm -rf R1
darcs get R R1

cd R1
echo yy | darcs rebase suspend
echo yy | darcs rebase suspend
echo yd | darcs pull ../R
echo yd | darcs rebase obliterate
echo yd | darcs rebase obliterate
cd ..

# issue2445: suspend, repull, unsuspend

rm -rf R2
darcs get R R2

cd R2
echo yy | darcs rebase suspend
echo yy | darcs rebase suspend
echo yd | darcs pull -a ../R
echo yd | darcs rebase unsuspend --allow-conflicts
echo yd | darcs pull -a ../R
echo yd | darcs rebase unsuspend
cd ..

# suspend, repull, suspend again, unsuspend

rm -rf R3
darcs get R R3

cd R3
echo yy | darcs rebase suspend
echo yy | darcs rebase suspend
echo yd | darcs pull -a ../R
echo yd | darcs pull -a ../R
echo yy | darcs rebase suspend
echo yy | darcs rebase suspend
echo wwyd | darcs rebase unsuspend
cd ..
